summaryrefslogtreecommitdiff
path: root/indra/newview/llfloaterreporter.cpp
diff options
context:
space:
mode:
authorAndrey Lihatskiy <alihatskiy@productengine.com>2021-03-09 21:58:57 +0200
committerAndrey Lihatskiy <alihatskiy@productengine.com>2021-03-09 21:58:57 +0200
commit1fe0033a7e8dc2b68fb1e5a25144fa0bc719b1af (patch)
tree0a4c8381d5815663f6bc84488f5945c27f6f8080 /indra/newview/llfloaterreporter.cpp
parent4f55a14f8281e7cccfa5c6980ad77921cb5ebdd8 (diff)
parent88d837c16e768c5262073a7df965066d4bd8842c (diff)
Merge branch 'master' into DRTVWR-483
Diffstat (limited to 'indra/newview/llfloaterreporter.cpp')
-rw-r--r--indra/newview/llfloaterreporter.cpp12
1 files changed, 8 insertions, 4 deletions
diff --git a/indra/newview/llfloaterreporter.cpp b/indra/newview/llfloaterreporter.cpp
index 5d0e2bbc55..7bfba2a6d7 100644
--- a/indra/newview/llfloaterreporter.cpp
+++ b/indra/newview/llfloaterreporter.cpp
@@ -44,7 +44,8 @@
#include "llnotificationsutil.h"
#include "llstring.h"
#include "llsys.h"
-#include "llfilesystem.h"
+#include "llvfile.h"
+#include "llvfs.h"
#include "mean_collision_data.h"
#include "message.h"
#include "v3math.h"
@@ -898,9 +899,12 @@ void LLFloaterReporter::takeScreenshot(bool use_prev_screenshot)
mResourceDatap->mAssetInfo.setName("screenshot_name");
mResourceDatap->mAssetInfo.setDescription("screenshot_descr");
- // store in cache
- LLFileSystem j2c_file(mResourceDatap->mAssetInfo.mUuid, mResourceDatap->mAssetInfo.mType, LLFileSystem::WRITE);
- j2c_file.write(upload_data->getData(), upload_data->getDataSize());
+ // store in VFS
+ LLVFile::writeFile(upload_data->getData(),
+ upload_data->getDataSize(),
+ gVFS,
+ mResourceDatap->mAssetInfo.mUuid,
+ mResourceDatap->mAssetInfo.mType);
// store in the image list so it doesn't try to fetch from the server
LLPointer<LLViewerFetchedTexture> image_in_list =